==> libssh-docs-0.11.1-1-x86_64.pkg.tar.zst: usr/share/doc/libssh/html/search/all_19.js <==
var searchData=
[
  ['passing_20a_20remote_20command_0',['Passing a remote command',['../libssh_tutor_command.html',1,'Chapter 4: Passing a remote command'],['../libssh_tutor_command.html#remote_command',1,'Passing a remote command']]],
  ['password_1',['Authenticating with a password',['../libssh_tutor_authentication.html#password',1,'']]],
  ['performing_20a_20download_20using_20the_20sftp_20aio_20api_2',['Performing a download using the sftp aio API',['../libssh_tutor_sftp_aio.html#sftp_aio_download_example',1,'']]],
  ['performing_20an_20asynchronous_20read_20write_20on_20a_20file_20on_20the_20remote_20computer_3',['Performing an asynchronous read/write on a file on the remote computer',['../libssh_tutor_sftp.html#sftp_aio',1,'']]],
  ['performing_20an_20upload_20using_20the_20sftp_20aio_20api_4',['Performing an upload using the sftp aio API',['../libssh_tutor_sftp_aio.html#sftp_aio_upload_example',1,'']]],
  ['pkcs_2011_20uris_5',['Chapter 9: Authentication using PKCS #11 URIs',['../libssh_tutor_pkcs11.html',1,'libssh_tutorial']]],
  ['pkcs_2011_20uris_20in_20libssh_6',['How to use PKCS #11 URIs in libssh?',['../libssh_tutor_pkcs11.html#how_to',1,'']]],
  ['policy_7',['Copyright Policy',['../index.html#main-copyright',1,'']]],
  ['poll_20functions_8',['The SSH poll functions',['../group__libssh__poll.html',1,'']]],
  ['port_20forwarding_9',['port forwarding',['../libssh_tutor_forwarding.html#forwarding_direct',1,'Direct port forwarding'],['../libssh_tutor_forwarding.html#forwarding_reverse',1,'Reverse port forwarding']]],
  ['port_20forwarding_20with_20libssh_10',['port forwarding with libssh',['../libssh_tutor_forwarding.html#libssh_direct',1,'Doing direct port forwarding with libssh'],['../libssh_tutor_forwarding.html#libssh_reverse',1,'Doing reverse port forwarding with libssh']]],
  ['pre_20requisites_20openssl_203_200_208_11',['Pre-requisites (OpenSSL 3.0.8+)',['../libssh_tutor_pkcs11.html#autotoc_md2',1,'']]],
  ['pre_20requisites_20openssl_203_200_20_3a_12',['Pre-requisites (OpenSSL &lt; 3.0):',['../libssh_tutor_pkcs11.html#autotoc_md1',1,'']]],
  ['protocol_20sftp_13',['Secure Shell File Transfer Protocol (SFTP)',['../index.html#main-rfc-sftp',1,'']]],
  ['public_20key_20infrastructure_14',['The SSH Public Key Infrastructure',['../group__libssh__pki.html',1,'']]],
  ['public_20keys_15',['Authenticating with public keys',['../libssh_tutor_authentication.html#pubkeys',1,'']]]
];

==> libssh-docs-0.11.2-1.1-x86_64.pkg.tar.zst: usr/share/doc/libssh/html/search/all_19.js <==
var searchData=
[
  ['passing_20a_20remote_20command_0',['Passing a remote command',['../libssh_tutor_command.html',1,'Chapter 4: Passing a remote command'],['../libssh_tutor_command.html#remote_command',1,'Passing a remote command']]],
  ['password_1',['Authenticating with a password',['../libssh_tutor_authentication.html#password',1,'']]],
  ['performing_20a_20download_20using_20the_20sftp_20aio_20api_2',['Performing a download using the sftp aio API',['../libssh_tutor_sftp_aio.html#sftp_aio_download_example',1,'']]],
  ['performing_20an_20asynchronous_20read_20write_20on_20a_20file_20on_20the_20remote_20computer_3',['Performing an asynchronous read/write on a file on the remote computer',['../libssh_tutor_sftp.html#sftp_aio',1,'']]],
  ['performing_20an_20upload_20using_20the_20sftp_20aio_20api_4',['Performing an upload using the sftp aio API',['../libssh_tutor_sftp_aio.html#sftp_aio_upload_example',1,'']]],
  ['pkcs_2011_20uris_5',['Chapter 9: Authentication using PKCS #11 URIs',['../libssh_tutor_pkcs11.html',1,'libssh_tutorial']]],
  ['pkcs_2011_20uris_20in_20libssh_6',['How to use PKCS #11 URIs in libssh?',['../libssh_tutor_pkcs11.html#how_to',1,'']]],
  ['policy_7',['Copyright Policy',['../index.html#main-copyright',1,'']]],
  ['poll_20functions_8',['The SSH poll functions',['../group__libssh__poll.html',1,'']]],
  ['port_20forwarding_9',['port forwarding',['../libssh_tutor_forwarding.html#forwarding_direct',1,'Direct port forwarding'],['../libssh_tutor_forwarding.html#forwarding_reverse',1,'Reverse port forwarding']]],
  ['port_20forwarding_20with_20libssh_10',['port forwarding with libssh',['../libssh_tutor_forwarding.html#libssh_direct',1,'Doing direct port forwarding with libssh'],['../libssh_tutor_forwarding.html#libssh_reverse',1,'Doing reverse port forwarding with libssh']]],
  ['pre_20requisites_20openssl_203_200_208_11',['Pre-requisites (OpenSSL 3.0.8+)',['../libssh_tutor_pkcs11.html#autotoc_md2',1,'']]],
  ['pre_20requisites_20openssl_203_200_20_3a_12',['Pre-requisites (OpenSSL &amp;lt; 3.0):',['../libssh_tutor_pkcs11.html#autotoc_md1',1,'']]],
  ['protocol_20sftp_13',['Secure Shell File Transfer Protocol (SFTP)',['../index.html#main-rfc-sftp',1,'']]],
  ['public_20key_20infrastructure_14',['The SSH Public Key Infrastructure',['../group__libssh__pki.html',1,'']]],
  ['public_20keys_15',['Authenticating with public keys',['../libssh_tutor_authentication.html#pubkeys',1,'']]]
];
